package backend

import (
	"fmt"
	"kpt-pasture/model"

	"gitee.com/xuyiping_admin/pkg/logger/zaplog"
	"go.uber.org/zap"

	pasturePb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/cow"
)

func (s *StoreEntry) BarnTypeEnumList() []*pasturePb.ConfigOptionsList {
	barnTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	barnTypeList = append(barnTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Lactating_Calves),
		Label:    "哺乳牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Weaned_Calves),
		Label:    "断奶牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Youth),
		Label:    "育成牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Nurturing),
		Label:    "育成牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Lactation),
		Label:    "泌乳牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Peripartum),
		Label:    "围产牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Dry_Milking),
		Label:    "干奶牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Sick_Cow),
		Label:    "病牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Out),
		Label:    "淘汰牛舍",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PenType_Segregate),
		Label:    "隔离牛舍",
		Disabled: true,
	})

	return barnTypeList
}

func (s *StoreEntry) BreedStatusEnumList() []*pasturePb.ConfigOptionsList {
	breedStatusList := make([]*pasturePb.ConfigOptionsList, 0)
	breedStatusList = append(breedStatusList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_UnBreed),
		Label:    "未配",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_Breeding),
		Label:    "已配未检",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_Pregnant),
		Label:    "怀孕",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_Empty),
		Label:    "空怀",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_Calving),
		Label:    "产犊",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_Abort),
		Label:    "流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.BreedStatus_No_Mating),
		Label:    "禁配",
		Disabled: true,
	})
	return breedStatusList
}

func (s *StoreEntry) CowKindEnumList() []*pasturePb.ConfigOptionsList {
	cowKindList := make([]*pasturePb.ConfigOptionsList, 0)
	cowKindList = append(cowKindList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_XMTEN),
		Label:    "西门塔尔牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_AGSN),
		Label:    "安格斯牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_XNLN),
		Label:    "夏洛莱牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_LMZN),
		Label:    "利木赞牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_HFTN),
		Label:    "海福特牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowKind_HN),
		Label:    "和牛",
		Disabled: true,
	})
	return cowKindList
}

func (s *StoreEntry) CowSourceEnumList() []*pasturePb.ConfigOptionsList {
	cowSourceList := make([]*pasturePb.ConfigOptionsList, 0)
	cowSourceList = append(cowSourceList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowSource_Calving),
		Label:    "产犊",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowSource_Transfer_In),
		Label:    "调入",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowSource_Buy),
		Label:    "购买",
		Disabled: true,
	})
	return cowSourceList
}
func (s *StoreEntry) CowTypeEnumList(optionName, isAll string) []*pasturePb.ConfigOptionsList {
	cowTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CowType_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	if optionName == "breed" {
		cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CowType_Reserve_Calf),
			Label:    "后备牛",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CowType_Breeding_Calf),
			Label:    "经产牛",
			Disabled: true,
		})
		return cowTypeList
	}

	cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Lactating_Calf),
		Label:    "哺乳犊牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Weaned_Calf),
		Label:    "育成牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Youth_Calf),
		Label:    "青年牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Fattening_Calf),
		Label:    "育肥牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Reserve_Calf),
		Label:    "后备牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Breeding_Calf),
		Label:    "种母牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Breeding_Bull),
		Label:    "种公牛",
		Disabled: true,
	})

	return cowTypeList
}

func (s *StoreEntry) SameTimeCowTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	cowTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.SameTimeStatus_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeCowType_Empty),
		Label:    "空怀牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeCowType_Breeding_Calf),
		Label:    "种母牛",
		Disabled: true,
	})
	return cowTypeList
}

func (s *StoreEntry) SameTimeTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	cowTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.SameTimeStatus_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeType_PGBJ),
		Label:    "PG保健",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeType_PGTQ),
		Label:    "PG同期",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeType_RnGH),
		Label:    "RnGH",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SameTimeType_TAI),
		Label:    "TAI输精",
		Disabled: true,
	})
	return cowTypeList
}

func (s *StoreEntry) ImmunizationCowTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	cowTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Lactating_Calf),
		Label:    "犊牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Weaned_Calf),
		Label:    "育成牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Youth_Calf),
		Label:    "青年牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Fattening_Calf),
		Label:    "育肥牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Reserve_Calf),
		Label:    "后备牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Reserve_Calf),
		Label:    "种母牛",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CowType_Breeding_Bull),
		Label:    "种公牛",
		Disabled: true,
	})
	return cowTypeList
}

func (s *StoreEntry) ImmunizationConditionsEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	cowTypeList := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ImmunizationConditions_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	cowTypeList = append(cowTypeList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.ImmunizationConditions_Days_Age),
		Label:    "日龄",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.ImmunizationConditions_Days_After_Delivery),
		Label:    "产后天数",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.ImmunizationConditions_Days_Of_Pregnancy),
		Label:    "怀孕天数",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.ImmunizationConditions_Admission_Days),
		Label:    "入场天数",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.ImmunizationConditions_Other_Vaccine_After),
		Label:    "基于其他疫苗之后",
		Disabled: true,
	})
	return cowTypeList
}

func (s *StoreEntry) TransferPenEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	transferPenList := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		transferPenList = append(transferPenList, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.TransferPenReason_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	transferPenList = append(transferPenList, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.TransferPenReason_Normal),
		Label:    "正常转群",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.TransferPenReason_Feed),
		Label:    "饲喂转群",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.TransferPenReason_Dry_Milk),
		Label:    "干奶转群",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.TransferPenReason_Pregnant),
		Label:    "怀孕转群",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.TransferPenReason_Overantibody),
		Label:    "过抗转群",
		Disabled: true,
	})
	return transferPenList
}

func (s *StoreEntry) ChildNumberEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.ChildNumber_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ChildNumber_One),
			Label:    "单胎",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ChildNumber_Two),
			Label:    "双胎",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ChildNumber_Three),
			Label:    "三胎",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ChildNumber_Four),
			Label:    "四胎",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) CalvingLevelEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.CalvingLevel_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CalvingLevel_Natural_Childbirth),
			Label:    "自然分娩",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CalvingLevel_Artificial_Midwifery1),
			Label:    "人工助产(1-2人)",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CalvingLevel_Artificial_Midwifery2),
			Label:    "人工助产(3人以上)",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.CalvingLevel_Caesarean_Section),
			Label:    "剖腹产",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) DystociaReasonEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.DystociaReason_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DystociaReason_Malposition),
			Label:    "胎位不正",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DystociaReason_Fetal_Overgrowth),
			Label:    "胎儿过大",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DystociaReason_Uterine_Atony),
			Label:    "子宫收缩无力",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DystociaReason_Pelvic_Stenosis),
			Label:    "盆骨狭小",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DystociaReason_Sub_Health),
			Label:    "母牛亚健康状态",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) PregnantCheckResultEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.PregnantCheckResult_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PregnantCheckResult_Pregnant),
		Label:    "有胎",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PregnantCheckResult_UnPregnant),
		Label:    "无胎",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) PregnantCheckMethodEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value: int32(pasturePb.PregnantCheckMethod_Invalid),
			})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PregnantCheckMethod_B_Ultrasound),
		Label:    "B超",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PregnantCheckMethod_Blood_Testing),
		Label:    "血检",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.PregnantCheckMethod_Manual_Inspection),
		Label:    "人工检查",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) DrugCategoryEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.DrugCategory_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Antibiotics),
		Label:    "抗生素类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Antivirals),
		Label:    "抗病毒类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Antifungals),
		Label:    "抗真菌类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Antiparasitics),
		Label:    "驱虫类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Analgesics),
		Label:    "镇痛类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Antipyretic),
		Label:    "退烧类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Vitamin),
		Label:    "维生素类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Brine),
		Label:    "盐水",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Glucose),
		Label:    "葡萄糖",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Hormone),
		Label:    "激素类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Anti_Stress),
		Label:    "抗应激类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Disinfect),
		Label:    "消毒类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Chinese_Herbal),
		Label:    "中药合剂",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Tocolytic),
		Label:    "保胎类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DrugCategory_Immunity),
		Label:    "疫苗类",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) DrugUsageEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.DrugUsage_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DrugUsage_Oral_Medications),
			Label:    "口服",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DrugUsage_Injectable_Medications),
			Label:    "肌注",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DrugUsage_Topical_Medications),
			Label:    "外用",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DrugUsage_Inhalation_Medications),
			Label:    "吸入",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DrugUsage_Drink_Medications),
			Label:    "饮水",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) UnitEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Pieces),
			Label:    "个",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Package),
			Label:    "包/袋",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Bottle),
			Label:    "瓶",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Box),
			Label:    "盒",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Boxful),
			Label:    "箱",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Branch),
			Label:    "支",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Barrel),
			Label:    "桶",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_Pot),
			Label:    "罐",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_ML),
			Label:    "毫升",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Unit_L),
			Label:    "升",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) ExposeEstrusTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.ExposeEstrusType_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}

	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ExposeEstrusType_Neck_Ring),
			Label:    "脖环揭发",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ExposeEstrusType_Foot_Ring),
			Label:    "脚环揭发",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.ExposeEstrusType_Natural_Estrus),
			Label:    "自然发情",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) FrozenSemenTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions,
			&pasturePb.ConfigOptionsList{
				Value:    int32(pasturePb.FrozenSemenType_Invalid),
				Label:    "全部",
				Disabled: true,
			})
	}
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.FrozenSemenType_Ordinary),
			Label:    "常规冻精",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.FrozenSemenType_Gender_Control),
			Label:    "性控冻精",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) BullNumberEnumList(isAll string) []*pasturePb.BullOptionsList {
	frozenSemenList := make([]*model.FrozenSemen, 0)
	bullNumberList := make([]*pasturePb.BullOptionsList, 0)
	if err := s.DB.Where("quantity > 0").Group("bull_id").Find(&frozenSemenList).Error; err != nil {
		zaplog.Error("BullNumberEnumList", zap.Any("Find", err))
	}

	for _, v := range frozenSemenList {
		bullNumberList = append(bullNumberList, &pasturePb.BullOptionsList{
			Value:    v.BullId,
			Label:    v.BullId,
			Disabled: true,
		})
	}
	return bullNumberList
}

func (s *StoreEntry) WeekEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions,
		&pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Monday),
			Label:    "周一",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Tuesday),
			Label:    "周二",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Wednesday),
			Label:    "周三",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Thursday),
			Label:    "周四",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Friday),
			Label:    "周五",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Saturday),
			Label:    "周六",
			Disabled: true,
		}, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.Week_Sunday),
			Label:    "周日",
			Disabled: true,
		})
	return configOptions
}

func (s *StoreEntry) MonthEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	for v := 1; v <= 31; v++ {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(v),
			Label:    fmt.Sprintf("%d号", v),
			Disabled: true,
		})
	}
	return configOptions
}

func (s *StoreEntry) WorkOrderFrequencyEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderFrequency_None),
		Label:    "一次性",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderFrequency_Daily),
		Label:    "每天",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderFrequency_Weekly),
		Label:    "每周",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderFrequency_Monthly),
		Label:    "每月",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) WorkOrderSubUnitEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderSubscribeUnit_Person),
		Label:    "个人",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderSubscribeUnit_dept),
		Label:    "部门",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) WorkOrderPriorityEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.Priority_Low),
		Label:    "低",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.Priority_Middle),
		Label:    "一般",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.Priority_High),
		Label:    "紧急",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) WorkOrderCategoryEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderCategory_Health),
		Label:    "保健",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderCategory_Breed),
		Label:    "繁殖",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderCategory_Nutrition),
		Label:    "营养",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderCategory_Ordinary),
		Label:    "日常",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.WorkOrderCategory_Other),
		Label:    "其他",
		Disabled: true,
	})
	return configOptions
}

func CalendarTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.SameTimeStatus_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_Immunisation),
		Label:    "免疫",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_PG),
		Label:    "同期PG",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_RnGH),
		Label:    "同期RnGH",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_Pregnancy_Check),
		Label:    "孕检",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_WorkOrder),
		Label:    "工单",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_Weaning),
		Label:    "断奶",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_Treatment),
		Label:    "治疗",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.CalendarType_Mating),
		Label:    "配种",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) AbortionReasonsEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.AbortionReasons_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Mechanical_Abortion),
		Label:    "机械性流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Malnutrition_Abortion),
		Label:    "营养不良性流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Mycotoxin_Abortion),
		Label:    "霉菌毒素流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Habitual_Abortion),
		Label:    "习惯性流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Brucellosis_Abortion),
		Label:    "布病流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Inflammatory_Abortion),
		Label:    "产道炎症性流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Heat_Stress_Abortion),
		Label:    "热应激流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Infectious_Abortion),
		Label:    "传染病性流产",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.AbortionReasons_Other),
		Label:    "其他",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) HealthStatusEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.HealthStatus_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}

	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Health),
		Label:    "健康",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Disease),
		Label:    "发病",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Treatment),
		Label:    "治疗",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Curable),
		Label:    "治愈",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Out),
		Label:    "淘汰",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.HealthStatus_Dead),
		Label:    "死亡",
		Disabled: true,
	})
	return configOptions
}
